"""
Blessed Pinterest connector for Airbyte SDK.

Auto-generated from OpenAPI specification.
"""

from .connector import PinterestConnector
from .models import (
    PinterestAuthConfig,
    PinterestReplicationConfig,
    AdAccountOwner,
    AdAccount,
    AdAccountsList,
    BoardMedia,
    BoardOwner,
    Board,
    BoardsList,
    CampaignTrackingUrls,
    Campaign,
    CampaignsList,
    AdGroupTrackingUrls,
    AdGroup,
    AdGroupsList,
    AdTrackingUrls,
    Ad,
    AdsList,
    BoardSection,
    BoardSectionsList,
    BoardPinBoardOwner,
    BoardPinMedia,
    BoardPin,
    BoardPinsList,
    Catalog,
    CatalogsList,
    CatalogsFeedPreferredProcessingSchedule,
    CatalogsFeed,
    CatalogsFeedsList,
    CatalogsProductGroup,
    CatalogsProductGroupsList,
    AudienceRule,
    Audience,
    AudiencesList,
    ConversionTagConfigs,
    ConversionTag,
    ConversionTagsList,
    CustomerList,
    CustomerListsList,
    Keyword,
    KeywordsList,
    AdAccountsListResultMeta,
    BoardsListResultMeta,
    CampaignsListResultMeta,
    AdGroupsListResultMeta,
    AdsListResultMeta,
    BoardSectionsListResultMeta,
    BoardPinsListResultMeta,
    CatalogsListResultMeta,
    CatalogsFeedsListResultMeta,
    CatalogsProductGroupsListResultMeta,
    AudiencesListResultMeta,
    ConversionTagsListResultMeta,
    CustomerListsListResultMeta,
    KeywordsListResultMeta,
    PinterestCheckResult,
    PinterestExecuteResult,
    PinterestExecuteResultWithMeta,
    AdAccountsListResult,
    BoardsListResult,
    CampaignsListResult,
    AdGroupsListResult,
    AdsListResult,
    BoardSectionsListResult,
    BoardPinsListResult,
    CatalogsListResult,
    CatalogsFeedsListResult,
    CatalogsProductGroupsListResult,
    AudiencesListResult,
    ConversionTagsListResult,
    CustomerListsListResult,
    KeywordsListResult,
    AirbyteSearchMeta,
    AirbyteSearchResult,
    AdAccountsSearchData,
    AdAccountsSearchResult,
    BoardsSearchData,
    BoardsSearchResult,
    CampaignsSearchData,
    CampaignsSearchResult,
    AdGroupsSearchData,
    AdGroupsSearchResult,
    AdsSearchData,
    AdsSearchResult,
    BoardSectionsSearchData,
    BoardSectionsSearchResult,
    BoardPinsSearchData,
    BoardPinsSearchResult,
    CatalogsSearchData,
    CatalogsSearchResult,
    CatalogsFeedsSearchData,
    CatalogsFeedsSearchResult,
    CatalogsProductGroupsSearchData,
    CatalogsProductGroupsSearchResult,
    AudiencesSearchData,
    AudiencesSearchResult,
    ConversionTagsSearchData,
    ConversionTagsSearchResult,
    CustomerListsSearchData,
    CustomerListsSearchResult,
    KeywordsSearchData,
    KeywordsSearchResult
)
from .types import (
    AdAccountsListParams,
    AdAccountsGetParams,
    BoardsListParams,
    BoardsGetParams,
    CampaignsListParams,
    AdGroupsListParams,
    AdsListParams,
    BoardSectionsListParams,
    BoardPinsListParams,
    CatalogsListParams,
    CatalogsFeedsListParams,
    CatalogsProductGroupsListParams,
    AudiencesListParams,
    ConversionTagsListParams,
    CustomerListsListParams,
    KeywordsListParams,
    AirbyteSearchParams,
    AirbyteSortOrder,
    AdAccountsSearchFilter,
    AdAccountsSearchQuery,
    AdAccountsCondition,
    BoardsSearchFilter,
    BoardsSearchQuery,
    BoardsCondition,
    CampaignsSearchFilter,
    CampaignsSearchQuery,
    CampaignsCondition,
    AdGroupsSearchFilter,
    AdGroupsSearchQuery,
    AdGroupsCondition,
    AdsSearchFilter,
    AdsSearchQuery,
    AdsCondition,
    BoardSectionsSearchFilter,
    BoardSectionsSearchQuery,
    BoardSectionsCondition,
    BoardPinsSearchFilter,
    BoardPinsSearchQuery,
    BoardPinsCondition,
    CatalogsSearchFilter,
    CatalogsSearchQuery,
    CatalogsCondition,
    CatalogsFeedsSearchFilter,
    CatalogsFeedsSearchQuery,
    CatalogsFeedsCondition,
    CatalogsProductGroupsSearchFilter,
    CatalogsProductGroupsSearchQuery,
    CatalogsProductGroupsCondition,
    AudiencesSearchFilter,
    AudiencesSearchQuery,
    AudiencesCondition,
    ConversionTagsSearchFilter,
    ConversionTagsSearchQuery,
    ConversionTagsCondition,
    CustomerListsSearchFilter,
    CustomerListsSearchQuery,
    CustomerListsCondition,
    KeywordsSearchFilter,
    KeywordsSearchQuery,
    KeywordsCondition
)
from ._vendored.connector_sdk.types import AirbyteHostedAuthConfig as AirbyteAuthConfig

__all__ = [
    "PinterestConnector",
    "AirbyteAuthConfig",
    "PinterestAuthConfig",
    "PinterestReplicationConfig",
    "AdAccountOwner",
    "AdAccount",
    "AdAccountsList",
    "BoardMedia",
    "BoardOwner",
    "Board",
    "BoardsList",
    "CampaignTrackingUrls",
    "Campaign",
    "CampaignsList",
    "AdGroupTrackingUrls",
    "AdGroup",
    "AdGroupsList",
    "AdTrackingUrls",
    "Ad",
    "AdsList",
    "BoardSection",
    "BoardSectionsList",
    "BoardPinBoardOwner",
    "BoardPinMedia",
    "BoardPin",
    "BoardPinsList",
    "Catalog",
    "CatalogsList",
    "CatalogsFeedPreferredProcessingSchedule",
    "CatalogsFeed",
    "CatalogsFeedsList",
    "CatalogsProductGroup",
    "CatalogsProductGroupsList",
    "AudienceRule",
    "Audience",
    "AudiencesList",
    "ConversionTagConfigs",
    "ConversionTag",
    "ConversionTagsList",
    "CustomerList",
    "CustomerListsList",
    "Keyword",
    "KeywordsList",
    "AdAccountsListResultMeta",
    "BoardsListResultMeta",
    "CampaignsListResultMeta",
    "AdGroupsListResultMeta",
    "AdsListResultMeta",
    "BoardSectionsListResultMeta",
    "BoardPinsListResultMeta",
    "CatalogsListResultMeta",
    "CatalogsFeedsListResultMeta",
    "CatalogsProductGroupsListResultMeta",
    "AudiencesListResultMeta",
    "ConversionTagsListResultMeta",
    "CustomerListsListResultMeta",
    "KeywordsListResultMeta",
    "PinterestCheckResult",
    "PinterestExecuteResult",
    "PinterestExecuteResultWithMeta",
    "AdAccountsListResult",
    "BoardsListResult",
    "CampaignsListResult",
    "AdGroupsListResult",
    "AdsListResult",
    "BoardSectionsListResult",
    "BoardPinsListResult",
    "CatalogsListResult",
    "CatalogsFeedsListResult",
    "CatalogsProductGroupsListResult",
    "AudiencesListResult",
    "ConversionTagsListResult",
    "CustomerListsListResult",
    "KeywordsListResult",
    "AirbyteSearchMeta",
    "AirbyteSearchResult",
    "AdAccountsSearchData",
    "AdAccountsSearchResult",
    "BoardsSearchData",
    "BoardsSearchResult",
    "CampaignsSearchData",
    "CampaignsSearchResult",
    "AdGroupsSearchData",
    "AdGroupsSearchResult",
    "AdsSearchData",
    "AdsSearchResult",
    "BoardSectionsSearchData",
    "BoardSectionsSearchResult",
    "BoardPinsSearchData",
    "BoardPinsSearchResult",
    "CatalogsSearchData",
    "CatalogsSearchResult",
    "CatalogsFeedsSearchData",
    "CatalogsFeedsSearchResult",
    "CatalogsProductGroupsSearchData",
    "CatalogsProductGroupsSearchResult",
    "AudiencesSearchData",
    "AudiencesSearchResult",
    "ConversionTagsSearchData",
    "ConversionTagsSearchResult",
    "CustomerListsSearchData",
    "CustomerListsSearchResult",
    "KeywordsSearchData",
    "KeywordsSearchResult",
    "AdAccountsListParams",
    "AdAccountsGetParams",
    "BoardsListParams",
    "BoardsGetParams",
    "CampaignsListParams",
    "AdGroupsListParams",
    "AdsListParams",
    "BoardSectionsListParams",
    "BoardPinsListParams",
    "CatalogsListParams",
    "CatalogsFeedsListParams",
    "CatalogsProductGroupsListParams",
    "AudiencesListParams",
    "ConversionTagsListParams",
    "CustomerListsListParams",
    "KeywordsListParams",
    "AirbyteSearchParams",
    "AirbyteSortOrder",
    "AdAccountsSearchFilter",
    "AdAccountsSearchQuery",
    "AdAccountsCondition",
    "BoardsSearchFilter",
    "BoardsSearchQuery",
    "BoardsCondition",
    "CampaignsSearchFilter",
    "CampaignsSearchQuery",
    "CampaignsCondition",
    "AdGroupsSearchFilter",
    "AdGroupsSearchQuery",
    "AdGroupsCondition",
    "AdsSearchFilter",
    "AdsSearchQuery",
    "AdsCondition",
    "BoardSectionsSearchFilter",
    "BoardSectionsSearchQuery",
    "BoardSectionsCondition",
    "BoardPinsSearchFilter",
    "BoardPinsSearchQuery",
    "BoardPinsCondition",
    "CatalogsSearchFilter",
    "CatalogsSearchQuery",
    "CatalogsCondition",
    "CatalogsFeedsSearchFilter",
    "CatalogsFeedsSearchQuery",
    "CatalogsFeedsCondition",
    "CatalogsProductGroupsSearchFilter",
    "CatalogsProductGroupsSearchQuery",
    "CatalogsProductGroupsCondition",
    "AudiencesSearchFilter",
    "AudiencesSearchQuery",
    "AudiencesCondition",
    "ConversionTagsSearchFilter",
    "ConversionTagsSearchQuery",
    "ConversionTagsCondition",
    "CustomerListsSearchFilter",
    "CustomerListsSearchQuery",
    "CustomerListsCondition",
    "KeywordsSearchFilter",
    "KeywordsSearchQuery",
    "KeywordsCondition",
]